Documentation
¶
Overview ¶
Package cmd provides the command-line interface for the get CLI.
Index ¶
Constants ¶
This section is empty.
Variables ¶
var Version = "dev"
Version is the version of the get CLI. It can be overridden at build time using -ldflags:
go build -ldflags "-X github.com/jclem/get/internal/cmd.Version=1.0.0"
Functions ¶
func ExecuteContext ¶
ExecuteContext creates a new root command and executes it with the given context.
This will run the CLI with any flags and arguments given to the current process.
func NewRootCmd ¶
NewRootCmd creates the root Cobra command for the get CLI.
func NewSessionsCmd ¶
NewSessionsCmd creates the `get sessions` command tree.
func NewVersionCmd ¶ added in v0.0.3
NewVersionCmd creates the `get version` command.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.